@@ -172,6 +172,9 @@ add_selected_contact (EmpathyContactSearchDialog *self)
   empathy_tp_contact_factory_get_from_id (conn, id,
       on_get_contact_factory_get_from_id_cb, NULL,
       NULL, NULL);
+
+  /* Close the dialog */
+  gtk_dialog_response (GTK_DIALOG (self), GTK_RESPONSE_CANCEL);
 }
 
 static void
@@ -387,12 +390,14 @@ supports_contact_search_cb (GObject *conn,
     gpointer user_data)
 {
   FilterCallbackData *data = user_data;
-  GError *myerr = NULL;
+  GError *error = NULL;
   TpCapabilities *caps;
 
-  if (!tp_proxy_prepare_finish (conn, result, &myerr))
+  if (!tp_proxy_prepare_finish (conn, result, &error))
     {
+      DEBUG ("Error preparing the connection: %s", error->message);
       data->callback (FALSE, data->user_data);
+      g_error_free (error);
       g_slice_free (FilterCallbackData, data);
       return;
     }
