@@ -30,7 +30,7 @@
 
 #include <libempathy/empathy-tp-contact-factory.h>
 #include <libempathy/empathy-contact-manager.h>
-#include <libempathy/empathy-dispatcher.h>
+#include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-utils.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
@@ -75,7 +75,7 @@ empathy_new_message_dialog_response (GtkDialog *dialog, int response_id)
 
   if (EMP_STR_EMPTY (contact_id) || account == NULL) goto out;
 
-  empathy_dispatcher_chat_with_contact_id (account, contact_id,
+  empathy_chat_with_contact_id (account, contact_id,
       gtk_get_current_event_time ());
 
 out:
@@ -90,40 +90,17 @@ conn_prepared_cb (GObject *conn,
   FilterCallbackData *data = user_data;
   GError *myerr = NULL;
   TpCapabilities *caps;
-  GPtrArray *classes;
-  guint i;
 
   if (!tp_proxy_prepare_finish (conn, result, &myerr))
-      goto out;
-
-  caps = tp_connection_get_capabilities (TP_CONNECTION (conn));
-  classes = tp_capabilities_get_channel_classes (caps);
-
-  for (i = 0; i < classes->len; i++)
     {
-      GHashTable *fixed;
-      GStrv allowed;
-      const gchar *chan_type;
-
-      tp_value_array_unpack (g_ptr_array_index (classes, i), 2,
-          &fixed, &allowed);
-
-      chan_type = tp_asv_get_string (fixed, TP_PROP_CHANNEL_CHANNEL_TYPE);
-
-      if (tp_strdiff (chan_type, TP_IFACE_CHANNEL_TYPE_TEXT))
-        continue;
-
-      if (tp_asv_get_uint32 (fixed, TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, NULL) !=
-          TP_HANDLE_TYPE_CONTACT)
-        continue;
-
-      data->callback (TRUE, data->user_data);
+      data->callback (FALSE, data->user_data);
       g_slice_free (FilterCallbackData, data);
-      return;
     }
 
-out:
-  data->callback (FALSE, data->user_data);
+  caps = tp_connection_get_capabilities (TP_CONNECTION (conn));
+  data->callback (tp_capabilities_supports_text_chats (caps),
+      data->user_data);
+
   g_slice_free (FilterCallbackData, data);
 }
 
