@@ -28,6 +28,8 @@
 
 #include <telepathy-glib/connection-manager.h>
 
+#include <libempathy/empathy-account-settings.h>
+
 G_BEGIN_DECLS
 
 #define EMPATHY_TYPE_PROTOCOL_CHOOSER (empathy_protocol_chooser_get_type ())
@@ -59,19 +61,24 @@ struct _EmpathyProtocolChooserClass
 };
 
 typedef gboolean (*EmpathyProtocolChooserFilterFunc) (TpConnectionManager *cm,
-    TpConnectionManagerProtocol *protocol, gpointer user_data);
+    TpConnectionManagerProtocol *protocol,
+    const gchar *service,
+    gpointer user_data);
 
 GType empathy_protocol_chooser_get_type (void) G_GNUC_CONST;
 GtkWidget * empathy_protocol_chooser_new (void);
 TpConnectionManager *empathy_protocol_chooser_dup_selected (
     EmpathyProtocolChooser *protocol_chooser,
     TpConnectionManagerProtocol **protocol,
-    gboolean *is_gtalk);
+    gchar **service);
 
 void empathy_protocol_chooser_set_visible (
     EmpathyProtocolChooser *protocol_chooser,
     EmpathyProtocolChooserFilterFunc func,
     gpointer user_data);
 
+EmpathyAccountSettings * empathy_protocol_chooser_create_account_settings (
+    EmpathyProtocolChooser *self);
+
 G_END_DECLS
 #endif /*  __EMPATHY_PROTOCOL_CHOOSER_H__ */
