@@ -28,7 +28,6 @@
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/util.h>
 
-#include <gconf/gconf-client.h>
 #include <pango/pango.h>
 #include <gdk/gdk.h>
 
@@ -48,8 +47,6 @@
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyThemeAdium)
 
-/* GConf key containing current value of font */
-#define EMPATHY_GCONF_FONT_KEY_NAME "/desktop/gnome/interface/document_font_name"
 #define BORING_DPI_DEFAULT 96
 
 /* "Join" consecutive messages with timestamps within five minutes */
@@ -252,14 +249,16 @@ static EmpathyStringParser string_parsers_with_smiley[] = {
 };
 
 static gchar *
-theme_adium_parse_body (const gchar *text)
+theme_adium_parse_body (EmpathyThemeAdium *self,
+	const gchar *text)
 {
+	EmpathyThemeAdiumPriv *priv = GET_PRIV (self);
 	EmpathyStringParser *parsers;
 	GString *string;
-	GSettings *gsettings = g_settings_new (EMPATHY_PREFS_CHAT_SCHEMA);
 
 	/* Check if we have to parse smileys */
-	if (g_settings_get_boolean (gsettings, EMPATHY_PREFS_CHAT_SHOW_SMILEYS))
+	if (g_settings_get_boolean (priv->gsettings_chat,
+	  EMPATHY_PREFS_CHAT_SHOW_SMILEYS))
 		parsers = string_parsers_with_smiley;
 	else
 		parsers = string_parsers;
@@ -270,7 +269,11 @@ theme_adium_parse_body (const gchar *text)
 	string = g_string_sized_new (strlen (text));
 	empathy_string_parser_substr (text, -1, parsers, string);
 
-	g_object_unref (gsettings);
+	/* Wrap body in order to make tabs and multiple spaces displayed
+	 * properly. See bug #625745. */
+	g_string_prepend (string, "<div style=\"display: inline; "
+					       "white-space: pre-wrap\"'>");
+	g_string_append (string, "</div>");
 
 	return g_string_free (string, FALSE);
 }
@@ -466,7 +469,7 @@ theme_adium_append_message (EmpathyChatView *view,
 		service_name = tp_account_get_protocol (account);
 	timestamp = empathy_message_get_timestamp (msg);
 	body = empathy_message_get_body (msg);
-	body_escaped = theme_adium_parse_body (body);
+	body_escaped = theme_adium_parse_body (theme, body);
 	name = empathy_contact_get_alias (sender);
 	contact_id = empathy_contact_get_id (sender);
 
@@ -749,7 +752,7 @@ theme_adium_context_menu_for_event (EmpathyThemeAdium *theme, GdkEventButton *ev
 	g_object_get (G_OBJECT (hit_test_result), "context", &context, NULL);
 
 	/* The menu */
-	menu = gtk_menu_new ();
+	menu = empathy_context_menu_new (GTK_WIDGET (view));
 
 	/* Select all item */
 	item = gtk_image_menu_item_new_from_stock (GTK_STOCK_SELECT_ALL, NULL);
@@ -810,8 +813,6 @@ theme_adium_context_menu_for_event (EmpathyThemeAdium *theme, GdkEventButton *ev
 	gtk_widget_show_all (menu);
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
 			event->button, event->time);
-	g_object_ref_sink (menu);
-	g_object_unref (menu);
 }
 
 static gboolean
@@ -978,24 +979,21 @@ theme_adium_inspect_web_view_cb (WebKitWebInspector *inspector,
 static PangoFontDescription *
 theme_adium_get_default_font (void)
 {
-	GConfClient *gconf_client;
+	GSettings *gsettings;
 	PangoFontDescription *pango_fd;
-	gchar *gconf_font_family;
+	gchar *font_family;
 
-	gconf_client = gconf_client_get_default ();
-	if (gconf_client == NULL) {
+	gsettings = g_settings_new (EMPATHY_PREFS_DESKTOP_INTERFACE_SCHEMA);
+
+	font_family = g_settings_get_string (gsettings,
+		     EMPATHY_PREFS_DESKTOP_INTERFACE_DOCUMENT_FONT_NAME);
+
+	if (font_family == NULL)
 		return NULL;
-	}
-	gconf_font_family = gconf_client_get_string (gconf_client,
-		     EMPATHY_GCONF_FONT_KEY_NAME,
-		     NULL);
-	if (gconf_font_family == NULL) {
-		g_object_unref (gconf_client);
-		return NULL;
-	}
-	pango_fd = pango_font_description_from_string (gconf_font_family);
-	g_free (gconf_font_family);
-	g_object_unref (gconf_client);
+
+	pango_fd = pango_font_description_from_string (font_family);
+	g_free (font_family);
+	g_object_unref (gsettings);
 	return pango_fd;
 }
 
